varying vec3 lightVec;
varying vec3 eyeVec;
varying vec2 texCoord;
uniform sampler2D colorMap;
uniform sampler2D normalMap;
uniform vec4 specular; // (material [will also use light 0 color])
uniform float shininess; // (material)

void main(void)
{
    float distSqr = dot(lightVec, lightVec);
    float att = clamp(1.0 - 0.001 * sqrt(distSqr), 0.0, 1.0); // 0.001 = invRadius
    vec3 lVec = lightVec * inversesqrt(distSqr);

    vec3 vVec = normalize(eyeVec);

    vec4 base = texture2D(colorMap, texCoord);
    vec3 bump = normalize(texture2D(normalMap, texCoord).xyz * 2.0 - 1.0);

    float ddiffuse = max(dot(lVec, bump), 0.0);
    vec4 vDiffuse = ddiffuse * vec4(0.8,0.8,0.8,1) * gl_LightSource[0].diffuse; // default GL diffuse value

    float dspecular = pow(clamp(dot(reflect(-lVec, bump), vVec), 0.0, 1.0), shininess);
    vec4 vSpecular = dspecular * specular * gl_LightSource[0].specular;

    vec4 ambient=vec4(0.2,0.2,0.2,1.0); // use default GL ambient color (0.2)
    gl_FragColor = (ambient * base + vDiffuse * base + vSpecular) * att;
}
